# Generated by Django 2.2.18 on 2021-02-23 21:54

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_dashboard', '0006_auto_20210219_1255'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='dashboard',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control']},
        ),
    ]



# Generated by Django 2.2.18 on 2021-02-19 11:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_dashboard', '0005_auto_20200619_1102'),
    ]

    operations = [
        migrations.AddField(
            model_name='dashboard',
            name='background',
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name='dashboard',
            name='target',
            field=models.CharField(default='default', max_length=20),
        ),
    ]



from django.db import models
from djangoldp.models import Model

SIZE_CHOICES = [
    ('1', '1'),
    ('2', '2'),
    ('3', '3')
]

class Dashboard(Model):
    target = models.CharField(max_length=20, default='default')
    size = models.CharField(max_length=1, choices=SIZE_CHOICES, default='1')
    background = models.BooleanField(default=True)
    content = models.TextField()
